==> ejc-jlincome-impl-3.0.0-20240516.114413-89-sources.jar: com/ejianc/business/jlincome/income/bean/DisclosureDepDetailsEntity.java <==
package com.ejianc.business.jlincome.income.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 收入管理-合同交底-部门明细子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_income_disclosure_department_details")
public class DisclosureDepDetailsEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="disclosure_id")
    private Long disclosureId; // 主表主键ID
    @TableField(value="disclosure_type_id")
    private Long disclosureTypeId; // 交底类型
    @TableField(value="disclosure_type_name")
    private String disclosureTypeName; // 交底类型名称
    @TableField(value="disclosure_departments")
    private String disclosureDepartments; // 交底参与部门
    @TableField(value="department_people")
    private String departmentPeople; // 部门负责人
    @TableField(value="disclosure_opinion")
    private String disclosureOpinion; // 交底意见
    @TableField(value="memo")
    private String memo; // 备注
    
    
    

    public Long getDisclosureId() {
        return disclosureId;
    }

    public void setDisclosureId(Long disclosureId) {
        this.disclosureId = disclosureId;
    }
    public Long getDisclosureTypeId() {
        return disclosureTypeId;
    }

    public void setDisclosureTypeId(Long disclosureTypeId) {
        this.disclosureTypeId = disclosureTypeId;
    }
    public String getDisclosureTypeName() {
        return disclosureTypeName;
    }

    public void setDisclosureTypeName(String disclosureTypeName) {
        this.disclosureTypeName = disclosureTypeName;
    }
    public String getDisclosureDepartments() {
        return disclosureDepartments;
    }

    public void setDisclosureDepartments(String disclosureDepartments) {
        this.disclosureDepartments = disclosureDepartments;
    }
    public String getDepartmentPeople() {
        return departmentPeople;
    }

    public void setDepartmentPeople(String departmentPeople) {
        this.departmentPeople = departmentPeople;
    }
    public String getDisclosureOpinion() {
        return disclosureOpinion;
    }

    public void setDisclosureOpinion(String disclosureOpinion) {
        this.disclosureOpinion = disclosureOpinion;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-jlincome-impl-3.0.0-20240713.013625-169-sources.jar: com/ejianc/business/jlincome/income/bean/DisclosureDepDetailsEntity.java <==
package com.ejianc.business.jlincome.income.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 收入管理-合同交底-部门明细子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_income_disclosure_department_details")
public class DisclosureDepDetailsEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="disclosure_id")
    private Long disclosureId; // 主表主键ID
    @TableField(value="disclosure_type")
    private String disclosureType; // 交底类型

    @TableField(value="disclosure_departments")
    private String disclosureDepartments; // 交底参与部门
    @TableField(value="department_people_id")
    private Long departmentPeopleId;//部门负责人id
    @TableField(value="department_people_name")
    private String departmentPeopleName;//部门负责人名称
    @TableField(value="disclosure_opinion")
    private String disclosureOpinion; // 交底意见
    @TableField(value="memo")
    private String memo; // 备注


    public String getDisclosureType() {
        return disclosureType;
    }

    public void setDisclosureType(String disclosureType) {
        this.disclosureType = disclosureType;
    }

    public Long getDepartmentPeopleId() {
        return departmentPeopleId;
    }

    public void setDepartmentPeopleId(Long departmentPeopleId) {
        this.departmentPeopleId = departmentPeopleId;
    }

    public String getDepartmentPeopleName() {
        return departmentPeopleName;
    }

    public void setDepartmentPeopleName(String departmentPeopleName) {
        this.departmentPeopleName = departmentPeopleName;
    }

    public Long getDisclosureId() {
        return disclosureId;
    }

    public void setDisclosureId(Long disclosureId) {
        this.disclosureId = disclosureId;
    }

    public String getDisclosureDepartments() {
        return disclosureDepartments;
    }

    public void setDisclosureDepartments(String disclosureDepartments) {
        this.disclosureDepartments = disclosureDepartments;
    }

    public String getDisclosureOpinion() {
        return disclosureOpinion;
    }

    public void setDisclosureOpinion(String disclosureOpinion) {
        this.disclosureOpinion = disclosureOpinion;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}
